@@ -14,7 +14,7 @@ Usage::
     client: AppConfigClient = boto3.client("appconfig")
     session_client: AppConfigClient = session.client("appconfig")
 """
-from mypy_boto3_appconfig.client import AppConfigClient, AppConfigClient as Client
+from mypy_boto3_appconfig.client import AppConfigClient as Client, AppConfigClient
 
 
 __all__ = ("AppConfigClient", "Client")
